clear all
set more off
set linesize 80



*** https://www.stata.com/statalist/archive/2013-01/msg01370.html

use mlm_cs_data1
quietly regress distress alliance
predict dist_res, residuals

local call

forvalues i = 0/9 {
	local call `call' line dist_res pid if tid == `i' + 1, connect(ascending) lcolor(gs`i') ||
}
twoway `call' , legend(off) scheme(lean2) ///
	xtitle("Patient ID")
	
	


mixed distress  || tid: 
estat icc


xtset tid pid
xtdescribe 
xtsum alliance distress

summarize distress
local dis_mean = r(mean)
summarize distress if tid == 1
local ther_mean = r(mean)
summarize distress if tid == 1 & pid == 9
local patient_ob = r(mean)
local dis_text = `patient_ob' + .25
local pat_text = `patient_ob' + .25
local ther_text = `ther_mean' + .3
twoway pci `patient_ob' 8.98 `dis_mean' 8.98, lwidth(medthick) lpattern(solid)  ///
	|| pci `patient_ob' 9.02 `ther_mean' 9.02, lwidth(medthick) lpattern(dash) ///
	|| pci `ther_mean' 9.02 `dis_mean' 9.02, lwidth(medthick) lpattern(dot) ///
	|| scatter distress pid if tid == 1 & pid == 9, ///
		msymbol(circle) msize(large) yline(`dis_mean', lpattern(longdash_dot)) ///
		xscale(range(8(1)10)) xlabel(none) ylabel(-2(.5).5) ///
	|| scatteri `ther_mean' 9, msymbol(diamond) msize(large) ///
	scheme(lean2) ytitle("Distress") ///
	text(`dis_text' 8.9 "R{subscript:ij}") ///
	text(`pat_text' 9.1 "e{subscript:ij}") ///
	text(`ther_text' 9.1 "u{subscript:ij}") ///
	legend(label(1 "Total residual (R{subscript:ij})") ///
		   label(2 "Patient residual (e{subscript:ij})") ///
		   label(3 "Therapist residual (u{subscript:j})") ///
		   label(4 "Patient distress") ///
		   label(5 "Therapist mean"))
	 



mixed distress || tid: , nolog

mixed, stddev noheader nofetable

estat icc

mixed distress alliance || tid:, nolog

quietly margins, at(alliance = (-3(0.5)3))
marginsplot, addplot(scatter distress alliance, mcolor(gs5%80) below) ///
	recastci(rarea) ciopts(fcolor(gs10%50)) ///
	xtitle("Alliance") ytitle("Expected distress") ///
	title("") xlabel(-4(1)4) scheme(lean2) ///
	legend(off)


estat icc

mixed distress || tid:

mixed alliance || tid: , nolog

estat icc

bysort tid: egen allmean = mean(alliance)
bysort tid: egen dismean = mean(distress)
egen tag = tag(tid)

regress dismean allmean if tag == 1

generate alldev = alliance - allmean
generate disdev = distress - dismean
regress disdev alldev


twoway scatter disdev alldev, msymbol(plus) mcolor(gs10%40) || ///
	   lfit disdev alldev || ///
	   scatter dismean allmean if tag == 1, msymbol(circle_hollow)  || /// 
	   lfit dismean allmean if tag == 1, lpattern(solid) ///
	   legend(label(1 "Within-therapist deviations") ///
			  label(2 "Within-therapist relationship") ///
			  label(3 "Between-therapist means") ///
			  label(4 "Between-therapist relationship") ///
			  position(6) rows(2) cols(2)) ///
	   xtitle("Alliance") ytitle("Distress") ///
	   scheme(lean2) 


mixed distress alldev allmean || tid: , nolog

lincom _b[allmean] - _b[alldev]

mixed distress alliance allmean || tid: , nolog





clear all 
set more off

use mlm_cs_data_extraicc

regress distress alliance
predict dist_res, residuals

preserve

keep dist_res tid pid

reshape wide dist_res, i(tid) j(pid)

corr dist_res1-dist_res8

restore


local call

forvalues i = 0/9 {
	local call `call' line dist_res pid if tid == `i' + 1, connect(ascending) lcolor(gs`i') ||
}

twoway `call' , legend(off) scheme(lean2) ///
	xtitle("Patient ID")


mixed distress alliance || tid: 
estat icc
