clear all
set linesize 80

use attractive
codebook, compact

table attract sex, c(mean years sd years p50 years n years) format(%9.2f)

table attract, by(sex) c(mean years sd years p50 years n years) format(%9.2f)

reshape wide years, i(id) j(attract)
graph box years0 years1, over(sex) ///
	ytitle("Years") ///
	legend(label(1 "Unattractive") label(2 "Attractive")) ///
	scheme(lean2) 


reshape long

egen twofact = group(attract sex)
quietly anova years twofact
margins twofact
marginsplot, plotopts(connect(none) msize(large)) scheme(lean2) ///
	xlabel(1 `" "Men" "Unattractive" "' ///
		   2 `" "Women" "Unattractive" "' ///
		   3 `" "Men" "Attractive" "' ///
		   4 `" "Women" "Attractive" "') ///
	plotregion(margin(20 20 0 0)) ///
	ylabel(0(1)6) xtitle("") ytitle("Sentence in years") ///
	title("") legend(off) ///
	addplot(scatter years twofact, jitter(3) msymbol(D) mcolor(gs10%30) below)
drop twofact

	

table attract sex, c(mean years n years) format(%9.2f) row col

// unattractive men interaction
display 4.77 - 3.99 -3.9 +3.65

// unattractive women interaction
display 3.22-3.99-3.39+3.65

// attractive men interaction
display 3.03-3.3-3.9+3.65

// attractive women interaction
display 3.57-3.3-3.39+3.65

anova years attract sex attract#sex

margins attract#sex
marginsplot, scheme(lean2) plotregion(margin(20 20 0 0)) ///
	ylabel(0(1)6) ytitle("Sentence in years") ///
	title("Defendant type by sex interaction") 

	
margins attract#sex
marginsplot

contrast sex@attract, effects mcompare(scheffe)

contrast attract@sex, effects mcompare(scheffe) 

margins attract@sex, contrast(effects) mcompare(scheffe) 


estat esize

estat esize, omega

table sex attract crime, c(mean years) format(%9.2f)

table attract crime, by(sex) c(mean years) format(%9.2f)

reshape wide years, i(id) j(attract)
graph box years0 years1, over(sex) by(crime, note("")) ///
	ytitle("Years") ///
	legend(label(1 "Unattractive") label(2 "Attractive")) ///
	scheme(lean2) 


reshape long

table attract sex, c(mean years) format(%9.2f)
table attract crime, c(mean years) format(%9.2f)
table sex crime, c(mean years) format(%9.2f)

table attract, c(mean years) format(%9.2f)
table sex, c(mean years) format(%9.2f)
table crime, c(mean years) format(%9.2f)


anova years attract sex crime attract#sex attract#crime sex#crime attract#sex#crime

quietly anova years attract sex crime attract#sex attract#crime sex#crime attract#sex#crime
margins attract#sex#crime
marginsplot, by(crime) byopts(title("")) scheme(lean2) ///
	plotregion(margin(10 10 0 0)) ///
	ylabel(0(1)10)  


marginsplot, xdimension(sex) by(crime) byopts(title("")) ///
	scheme(lean2) ///
	plotregion(margin(10 10 0 0)) ///
	ylabel(0(1)10)  
	

contrast attract#sex@crime, mcompare(scheffe) noeffects   

contrast attract@sex#crime, mcompare(scheffe) pveffects nowald

estat esize, omega
