clear all

set linesize 80
power twomeans 0 .25, sd(1) n(10(10)1000) saving(power_test, replace)

use power_test

expand 200
sort N

set seed 123

gen se = sqrt((N1+N2)/(N1*N2) + (delta^2)/(2*(N1+N2)))

gen data = rnormal(.25, se)

gen z = data/(sqrt((N1+N2)/(N1*N2) + (data^2)/(2*(N1+N2))))

gen sig = z >= 1.96 | z <= -1.96

twoway (scatter power data if sig == 0, msymbol(circle_hollow) mcolor(gs12)) ///
	   (scatter power data if sig == 1, msymbol(triangle_hollow) mcolor(gs6)) ///
	   (scatteri 0 0 1 0 , recast(line) lpattern(dash) lwidth(thick) lcolor(gray)) ///
	   (scatteri 0 .25 1 .25, recast(line) lwidth(thick)), ///
	   xmlabel(0.25) scheme(lean2)  ///
	   xtitle("Effect estimate") ytitle("Power") ///
	   legend(order(1 "p > .05" 2 "p {&le} .05") ///
	   position(3) cols(1))


clear all


*** This gives a consistent answer to Gelman's function
*** from his paper

local delta = .2
local s = sqrt((1/10) + (1/10))
local probneg = normal(((-`delta'/`s') - 1.96))
local power = normal(((`delta'/`s') - 1.96)) + normal(((-`delta'/`s') - 1.96))
display "Type S Error Rate is " `probneg'/`power'



clear all
local a = 1
set obs 8918
gen types = .
gen power = .
forvalues i = .01(.01).99 {
	forvalues j = 10(1)100 {
		local d = `i'
		local s = sqrt((1/`j') + (1/`j'))
		local probneg = normal(((-`d'/`s') - 1.96))
		local power = normal(((`d'/`s') - 1.96)) + normal(((-`d'/`s') - 1.96))
		local types = `probneg'/`power'
		quietly replace types = `types' in `a'
		quietly replace power = `power' in `a'
		local a = `a' + 1
	}
}
	
sort power

twoway line types power, xline(.0964502, lpattern(dash)) ///
			yline(0.05, lpattern(dot)) ///
			ytitle("Type S error rate") ///
			xtitle("Power") ///
			scheme(lean2)

clear all
set obs 10000 // sample 10000 times
set seed 29446
gen estimate =  rnormal(.2, .45) // sample effect sizes	
gen sig = abs(estimate)/.45 > 1.96 // is the sample effect significant?
by sig, sort: egen mean_est = mean(abs(estimate)) // what is the average of the absolute values of the estimate?
egen exag_tag = tag(sig) // tag a single significant value
gen exag = mean_est/.2 if exag_tag == 1 // divide the average estimated value by the population value to determine exaggeration
list exag if exag_tag == 1 & sig == 1 // what is the exaggeration ratio?

//forvalues i = 0.1



// power = normal(((`d'/`s') - 1.96)) + normal(((-`d'/`s') - 1.96))

clear all

program define exaggerate, rclass
	drop _all
	syntax [, obs(integer 10000) d(real 0.2) n(integer 10)]
	set obs `obs'
	local se =  sqrt((`n'+`n')/(`n'*`n') + (`d'^2)/(2*(`n'+ `n')))
	local power = normal(((`d'/`se') - 1.96)) + normal(((-`d'/`se') - 1.96))
	gen estimate = rnormal(`d', `se')
	gen sig = abs(estimate)/`se' > 1.96
	by sig, sort: egen mean_est = mean(abs(estimate))
	egen exag_tag = tag(sig)
	gen exag = mean_est/`d' if exag_tag == 1
	keep if exag_tag == 1 & sig == 1
	return scalar exag = exag
	return scalar power = `power'
end


local a = 1
forvalues i = .01(.01).99 {
	forvalues j = 10(1)100 {
		quietly simulate exag = r(exag) power = r(power), reps(1) saving("rep`a'", replace): exaggerate, obs(10000) d(`i') n(`j') 
		local a = `a' + 1
		}
	}

clear all
	
forvalues i = 2(1)8918 {
	append using "rep`i'"
}

sort power

drop if exag > 10

twoway line exag power, ///
			ytitle("Exaggeration ratio") ///
			xtitle("Power") ///
			xline(.25, lpattern(dash)) ///
			yline(1, lpattern(dot)) ///
			scheme(lean2)
			
