// Scott Baldwin: initially created on 2015_08_25
// edited: 2015_08_27
// edited: 2015_09_02
// edited: 2015_09_03
// edited: 2015_09_11
// edited: 2015_09_14
// edited: 2015_09_15
// edited: 2016_06_06

version 15
clear all
set more off
macro drop _all
set linesize 80


use "gss_attitude", clear

histogram attitude, scheme(lean2) bin(19)

summarize attitude

summarize attitude, detail


capture program drop simdemo

program define simdemo, rclass
	version 15
	drop _all
	set obs 1
	generate new_attitude = rnormal(2.4, .5)
	generate diff_mean = (new_attitude - 2.4)^2
	generate diff_p75 = (new_attitude - 3.33)^2
	generate mean_small = diff_mean < diff_p75
	return scalar mean_small = mean_small
end
simulate mean_smaller = r(mean_small), reps(10000) nodots seed(38499): simdemo

tabulate mean_smaller



use "gss_attitude", clear

twoway scatter attitude educ, jitter(2) scheme(lean2)

twoway (scatter attitude educ, jitter(2)) ///
	   (lfit attitude educ), scheme(lean2) ///
	   legend(position(6))

regress attitude educ

quietly summarize educ
generate educ_c = educ - r(mean)

regress attitude educ_c

quietly regress attitude educ
predict res_att, residual

quietly regress attitude educ
margins, at(educ = 15)

quietly regress attitude educ
margins, at(educ = (10(2)20))




use "gss_attitude", clear
set seed 123
sample 5
regress attitude educ
predict pred_att
predict res_att, residual
generate educn = educ + runiform(-.49, .49)

twoway (rspike attitude pred_att educn) ///
	   (lfit pred_att educn) ///
	   (scatter attitude educn, msymbol(circle)), ///
	   legend(off) scheme(lean2) ///
	   xtitle("Education") ytitle("Attitude")

use "gss_attitude", clear
set seed 123
sample 5
regress attitude educ
predict pred_att
predict res_att, residual
generate educn = educ + runiform(-.49, .49)


quietly summarize attitude
local a = r(mean)
egen meanatt = mean(attitude)
generate educn2 = educn+.1

** removing an obs to make the graph easier to read
drop if age == 70 & educ == 20 


twoway (rspike attitude pred_att educn, lpattern(dot)) ///
	   (lfit pred_att educn) ///
	   (rspike pred_att meanatt educn in 23, lpattern(solid)) ///
	   (rspike attitude meanatt educn2 in 23, lpattern(dash)) /// 
	   (scatter attitude educn, msymbol(circle)), ///
	   yline(`a') legend(off) scheme(lean2) ///
	   xtitle("Education") ytitle("Attitude")



clear
set obs 9

egen x = seq(), from(0) to(8)
generate b = 1
generate m = .5
generate y = m*x+b


twoway scatter y x, connect(L) scheme(lean2) ///
	ylabel(0(1)6) xlabel(0(1)8) text(5.5 1 "y = .5x + 1", size(large))


