clear all
set more off
set linesize 80

use early_child

capture program drop adjfit

program adjfit, rclass
	syntax namelist(name = namelist id = "SEM Estimation Results Required" max=2 local)
	local res nullchi nulldf modelchi modeldf tli adjcfi
	tempname `res'
	quietly estimates restore `1'
	scalar `nullchi' = e(chi2_ms)
	scalar `nulldf' = e(df_ms)
	quietly estimates restore `2'
	scalar `modelchi' = e(chi2_ms)
	scalar `modeldf' = e(df_ms)
	scalar `adjcfi' = 1 - ((`modelchi' - `modeldf')/(max(`nullchi' - `nulldf', `modelchi' - `modeldf')))
	return scalar adjcfi = `adjcfi'
	display "The null model is `1'"
	display "The proposed model is `2'"
	display "The Adjusted CFI is " round(`adjcfi', 0.001)
end


sem (CONCEN1 -> concent1 involved1 absorb1 wait1) ///
	(CONCEN2 -> concent2 involved2 absorb2 wait2), coeflegend nolog

// null model
sem (concent1 involved1 absorb1 wait1 concent2 involved2 absorb2 wait2), ///
	mean(concent1@m1 concent2@m1 involved1@m2 involved2@m2 ///
		absorb1@m3 absorb2@m3 wait1@m4 wait2@m4) ///
	covstruct(_OEx, diagonal) ///
	var(concent1@v1 concent2@v1 involved1@v2 involved2@v2 ///
		absorb1@v3 absorb2@v3 wait1@v4 wait2@v4)
estimates store null

// intercepts for time 1
constraint 1  _b[concent1:_cons] = 0 - _b[involved1:_cons] - _b[absorb1:_cons] - _b[wait1:_cons]
// loadings for time 1
constraint 2  _b[concent1:CONCEN1] = 4 - _b[involved1:CONCEN1] - _b[absorb1:CONCEN1] - _b[wait1:CONCEN1]
// intercepts for time 2
constraint 3 _b[concent2:_cons] = 0 - _b[involved2:_cons] - _b[absorb2:_cons] - _b[wait2:_cons]
// loadings for time 2
constraint 4  _b[concent2:CONCEN2] = 4 - _b[involved2:CONCEN2] - _b[absorb2:CONCEN2] - _b[wait2:CONCEN2]

	
// configural 
sem (CONCEN1 -> concent1 involved1 absorb1 wait1) ///
	(CONCEN2 -> concent2 involved2 absorb2 wait2), ///
	mean(CONCEN1@mean1)	mean(CONCEN2@mean2) ///
	var(CONCEN1@var1) var(CONCEN2@var2) ///
	cov(e.concent1*e.concent2) cov(e.involved1*e.involved2) ///
	cov(e.absorb1*e.absorb2) cov(e.wait1*e.wait2) ///
	constraints(1/4) 
estimates store configural
adjfit null configural 
estadd scalar adjcfi = r(adjcfi)
	
		
sem, standardized

// metric
sem (CONCEN1 -> concent1@l1 involved1@l2 absorb1@l3 wait1@l4) ///
	(CONCEN2 -> concent2@l1 involved2@l2 absorb2@l3 wait2@l4), ///
	mean(CONCEN1@mean1)	mean(CONCEN2@mean2) ///
	var(CONCEN1@var1) var(CONCEN2@var2) ///
	cov(e.concent1*e.concent2) cov(e.involved1*e.involved2) ///
	cov(e.absorb1*e.absorb2) cov(e.wait1*e.wait2) ///
	constraints(1 2 3) 
estimates store metric
estadd lrtest configural
adjfit null metric
estadd scalar adjcfi = r(adjcfi)


// scalar
sem (CONCEN1 -> concent1@l1 involved1@l2 absorb1@l3 wait1@l4) ///
	(CONCEN2 -> concent2@l1 involved2@l2 absorb2@l3 wait2@l4) ///
	(concent1 concent2 <- _cons@m1) ///
	(involved1 involved2 <- _cons@m2) ///
	(absorb1 absorb2 <- _cons@m3) ///
	(wait1 wait2 <- _cons@m4) , ///
	mean(CONCEN1@mean1) mean(CONCEN2@mean2) ///
	var(CONCEN1@var1) var(CONCEN2@var2) ///
	cov(e.concent1*e.concent2) cov(e.involved1*e.involved2) ///
	cov(e.absorb1*e.absorb2) cov(e.wait1*e.wait2) ///
	constraints(1 2)
estimates store scalar	
estadd lrtest metric	
adjfit null scalar
estadd scalar adjcfi = r(adjcfi)	

// residual 
sem (CONCEN1 -> concent1@l1 involved1@l2 absorb1@l3 wait1@l4) ///
	(CONCEN2 -> concent2@l1 involved2@l2 absorb2@l3 wait2@l4) ///
	(concent1 concent2 <- _cons@m1) ///
	(involved1 involved2 <- _cons@m2) ///
	(absorb1 absorb2 <- _cons@m3) ///
	(wait1 wait2 <- _cons@m4) , ///
	mean(CONCEN1@mean1) mean(CONCEN2@mean2) ///
	var(CONCEN1@var1) var(CONCEN2@var2) ///
	cov(e.concent1*e.concent2) cov(e.involved1*e.involved2) ///
	cov(e.absorb1*e.absorb2) cov(e.wait1*e.wait2) ///
	var(e.concent1@e1) var(e.concent2@e1) ///
	var(e.involved1@e2) var(e.involved2@e2) ///
	var(e.absorb1@e3) var(e.absorb2@e3) ///
	var(e.wait1@e4) var(e.wait2@e4) ///
	constraints(1 2)
estimates store residual
estadd lrtest scalar
adjfit null residual
estadd scalar adjcfi = r(adjcfi)

// structural -- variance	
sem (CONCEN1 -> concent1@l1 involved1@l2 absorb1@l3 wait1@l4) ///
	(CONCEN2 -> concent2@l1 involved2@l2 absorb2@l3 wait2@l4) ///
	(concent1 concent2 <- _cons@m1) ///
	(involved1 involved2 <- _cons@m2) ///
	(absorb1 absorb2 <- _cons@m3) ///
	(wait1 wait2 <- _cons@m4) , ///
	mean(CONCEN1@mean1) mean(CONCEN2@mean2) ///
	var(CONCEN1@var1) var(CONCEN2@var1) ///
	cov(e.concent1*e.concent2) cov(e.involved1*e.involved2) ///
	cov(e.absorb1*e.absorb2) cov(e.wait1*e.wait2) ///
	var(e.concent1@e1) var(e.concent2@e1) ///
	var(e.involved1@e2) var(e.involved2@e2) ///
	var(e.absorb1@e3) var(e.absorb2@e3) ///
	var(e.wait1@e4) var(e.wait2@e4) ///
	constraints(1 2)
estimates store struct_var
estadd lrtest residual
adjfit null struct_var
estadd scalar adjcfi = r(adjcfi)

// structural -- mean and variance 	
sem (CONCEN1 -> concent1@l1 involved1@l2 absorb1@l3 wait1@l4) ///
	(CONCEN2 -> concent2@l1 involved2@l2 absorb2@l3 wait2@l4) ///
	(concent1 concent2 <- _cons@m1) ///
	(involved1 involved2 <- _cons@m2) ///
	(absorb1 absorb2 <- _cons@m3) ///
	(wait1 wait2 <- _cons@m4) , ///
	mean(CONCEN1@mean1) mean(CONCEN2@mean1) ///
	var(CONCEN1@var1) var(CONCEN2@var1) ///
	cov(e.concent1*e.concent2) cov(e.involved1*e.involved2) ///
	cov(e.absorb1*e.absorb2) cov(e.wait1*e.wait2) ///
	var(e.concent1@e1) var(e.concent2@e1) ///
	var(e.involved1@e2) var(e.involved2@e2) ///
	var(e.absorb1@e3) var(e.absorb2@e3) ///
	var(e.wait1@e4) var(e.wait2@e4) ///
	constraints(1 2)
estimates store struct_mean_var
estadd lrtest struct_var
adjfit null struct_mean_var
estadd scalar adjcfi = r(adjcfi)

esttab configural metric scalar residual struct_var struct_mean_var ///
		using "long_invar_table.tex", ///
	   longtable booktabs alignment(D{.}{.}{-1}) ///
	varwidth(15) b(2) not nostar ///
	stats(N lrtest_chi2 lrtest_df lrtest_p adjcfi, ///
		  labels("\$N$" "\$\chi^2_{diff}$" "\$df$" "\$p$" "Adj. CFI") ///
		  fmt(0 2 0 3 3)) substitute(\_ _) ///
	varlabels(concent1:CONCEN1 "\$\lambda_{1}$" ///
			  concent1:_cons "\$\tau_{1}$" ///
			  involved1:CONCEN1 "\$\lambda_{2}$" ///
			  involved1:_cons "\$\tau_{2}$" ///
			  absorb1:CONCEN1 "\$\lambda_{3}$" ///
			  absorb1:_cons "\$\tau_{3}$" ///
			  wait1:CONCEN1 "\$\lambda_{4}$" ///
			  wait1:_cons "\$\tau_{4}$" ///
			  concent2:CONCEN2 "\$\lambda_{5}$" ///
			  concent2:_cons "\$\tau_{5}$" ///
			  involved2:CONCEN2 "\$\lambda_{6}$" ///
			  involved2:_cons "\$\tau_{6}$" ///
			  absorb2:CONCEN2 "\$\lambda_{7}$" ///
			  absorb2:_cons "\$\tau_{7}$" ///
			  wait2:CONCEN2 "\$\lambda_{8}$" ///
			  wait2:_cons "\$\tau_{8}$" ///
			  mean(CONCEN1):_cons "\$\kappa_{1}$" ///
			  mean(CONCEN2):_cons "\$\kappa_{2}$" ///
			  var(CONCEN1):_cons "\$\phi_{1}$" ///
			  var(CONCEN2):_cons "\$\phi_{2}$" ///
			  var(e.concent1):_cons "\$\theta_{1}$" ///
			  var(e.involved1):_cons "\$\theta_{2}$" ///
			  var(e.absorb1):_cons "\$\theta_{3}$" ///
			  var(e.wait1):_cons "\$\theta_{4}$" ///
			  var(e.concent2):_cons "\$\theta_{5}$" ///
			  var(e.involved2):_cons "\$\theta_{6}$" ///
			  var(e.absorb2):_cons "\$\theta_{7}$" ///
			  var(e.wait2):_cons "\$\theta_{8}$" ///
			  cov(e.concent1,e.concent2):_cons "\$\theta_{15}$" ///
			  cov(e.involved1,e.involved2):_cons "\$\theta_{26}$" ///
			  cov(e.absorb1,e.absorb2):_cons "\$\theta_{37}$" ///
			  cov(e.wait1,e.wait2):_cons "\$\theta_{48}$" ///
			  cov(CONCEN1,CONCEN2):_cons "\$\phi_{12}$") ///
	title(Concentration longitudinal invariance results\label{tab:longinvartab}) ///
	addnote("Note. The first two coefficients" "for every outcome are the loadings and the second two are intercepts.") ///
	mtitles("Configural" "Metric" "Scalar" "Residual" "Variance" "Mean") replace
			  
			  
