clear all
set more off

set linesize 80

use mlm_long

by id: generate diff = distress[_n] - distress[_n - 1]

list id time distress diff in 1/18, clean

table time, c(mean diff sd diff min diff max diff) format(%9.2f)

histogram diff if time > 1, by(time) xlabel(-5(1)5) xtitle("Difference") scheme(lean2)


twoway (scatter distress time, connect(L)) if id < 13, ///
	by(id) xlabel(1(1)6) scheme(lean2)
	

twoway (scatter distress time) (lfit distress time) if id < 13, ///
	by(id, legend(off)) xlabel(1(1)6) ytitle("Psychological distress") ///
	 scheme(lean2) 


generate time_c = time - 1

statsby intercept = _b[_cons] slope = _b[time] ///
		int_se = _se[_cons] slope_se = _se[time] ///
		df = e(df_r), by(id) clear: regress distress time_c

summarize intercept slope

generate ll_b = slope - (slope_se*(-1*invt(df, .025)))
generate ul_b = slope + (slope_se*(-1*invt(df, .025)))
egen therrank = rank(slope)

twoway scatter slope therrank || ///
	rcap ul_b ll_b therrank, ///
	ytitle("Distress-time slope") xtitle("Patient rank") ///
	legend(off) ///
	scheme(lean2)
	

corr intercept slope

twoway scatter slope intercept || ///
	   lfit slope intercept, legend(off) ///
		ytitle("Patient-specific slope") ///
		xtitle("Patient-specific intercept") ylabel(-3(1)3) xlabel(-5(1)5) ///
		scheme(lean2)



use mlm_long, clear

generate time_c = time - 1
mixed distress c.time_c || id: , nolog
estimates store randint

mixed distress c.time_c || id:time_c, covariance(unstructured) nolog
estimates store randslope

lrtest randint randslope

quietly mixed distress c.time_c || id:time_c, covariance(unstructured)
quietly margins, at(time = (0(1)5))
marginsplot, recastci(rarea) ciopts(color(gs10%50)) ///
	ytitle("Expected distress") scheme(lean2)


predict ex_distress, fitted
twoway scatter ex_distress time_c if time_c == 0, msymbol(circle_hollow) color(black) || ///
	   scatter ex_distress time_c if time_c > 0, msymbol(triangle_hollow) color(gs5) || ///
	   line ex_distress time_c, lpattern(solid) lcolor(gs10%50) connect(ascending) ///
	   ytitle("Distress") xtitle("Time") ///
	   legend(order(1 "Random intercepts" ///
					2 "Expected values" ///
					3 "Random slopes")) scheme(lean2)



mixed distress c.time_c i.tx || id:time_c, covariance(unstructured) stddeviations nolog
quietly margins tx, at(time = (0(1)5))
marginsplot, recastci(rarea) ///
	ci1opts(color(gs10%50)) ci2opts(color(gs5%50)) ///
	ytitle("Predicted distress") xtitle("Time") ///
	title("") scheme(lean2)

mixed distress c.time_c i.tx c.time_c#i.tx || id:time_c, covariance(unstructured) stddeviations nolog

quietly margins tx, at(time_c = (0(1)5))
marginsplot, recastci(rarea) ///
	ci1opts(color(gs10%50)) ci2opts(color(gs5%50)) ///
	ytitle("Predicted distress") xtitle("Time") ///
	title("") scheme(lean2)


mixed distress c.time_c i.tx c.time_c#i.tx || id:time, covariance(unstructured) stddeviations nolog coeflegend

lincom _b[_cons] + _b[1.tx] // CBT intercept/baseline distress
lincom _b[time_c] +  _b[1.tx#c.time_c] // CBT rate of change

mixed distress ibn.tx ibn.tx#c.time_c, nocons || id:time_c, covariance(unstructured) stddeviations nolog 

mixed distress c.time_c##i.tx stress || id:time_c, covariance(unstructured) stddeviations nolog

summarize stress

quietly mixed distress c.time_c##i.tx stress || id:time_c, covariance(unstructured) stddeviations nolog
quietly margins tx, at(time_c = (0(1)5) stress = (-1(1)1)) 

marginsplot, noci by(tx) byopts(title("")) ytitle("Expected distress") ///
		legend(order(1 "Stress = 1" 2 "Stress = 0" 3 "Stress = 1") rows(1)) ///
		scheme(lean2)


use mlm_long, clear

graph box distress stress, over(time) by(tx) ytitle("Distress") scheme(lean2)


table tx time, c(mean distress mean stress) format(%9.2f)
