clear all
set more off
set linesize 80


use mlm_cs_data1
by tid, sort: egen nopooled = mean(distress)

by tid: egen npse = semean(distress)
generate npll = nopooled - npse*1.96
generate npul = nopooled + npse*1.96

egen ther_tag = tag(tid) 
egen nptrank = rank(nopooled) if ther_tag == 1

twoway scatter nopooled nptrank if ther_tag == 1 || ///
	rcap npul npll nptrank if ther_tag == 1, ///
	xtitle("Therapist rank") ytitle("Distress") ///
	legend(order(1 "Unpooled mean")) scheme(lean2)



quietly mixed distress || tid: , nolog
predict u_i, reffects
predict uses, reses
generate pooled = _b[_cons] + u_i

generate pll = pooled - uses*1.96
generate pul = pooled + uses*1.96
egen ptrank = rank(pooled) if ther_tag == 1
twoway scatter pooled ptrank if ther_tag == 1 || ///
	rcap pul pll ptrank if ther_tag == 1, ///
	xtitle("Therapist rank") ytitle("Distress") ylabel(-2(1)2) ///
	legend(order(1 "Pooled mean")) scheme(lean2)


	
summarize nopooled pooled if ther_tag == 1



twoway scatter pooled nopooled if ther_tag == 1 ///
	|| function y = x, range(nopooled) xline(-0.08) ///
	ytitle("Pooled mean") xtitle("Unpooled mean") ///
	scheme(lean2) legend(off)


	
graph dot pooled nopooled if tid < 21 & ther_tag == 1, ///
	over(tid) yline(-0.08) ///
	legend(label(1 "Pooled mean") label(2 "Unpooled mean")) ///
	ytitle("Distress") ylabel(-1.5(.5)1.5) scheme(lean2)



*twoway dot pooled tid if tid < 21 & ther_tag == 1, horizontal || ///
*	dot nopooled tid if tid < 21 & ther_tag == 1, scheme(lean2) horizontal || ///
*	function normalden(x, 0, sqrt(.1837214)), range(-2 2) yaxis(2)


clear all
set more off

use mlm_cs_data1

// drop some obs from a couple of therapists

set seed 387
sample 2 if tid == 4, count
sample 5 if tid == 10, count
sample 10 if tid == 28, count
sample 13 if tid == 29, count



regress distress i.tid
predict nopool4, xb


mixed distress || tid:, coeflegend
predict pooled3, reffects
generate pooled4 = _b[_cons] + pooled

summarize pooled4 nopool

by tid, sort: egen caseload = count(tid)

scatter pooled4 nopool [w = caseload], mcolor(%50) || function x, range(nopool) scheme(lean2)

scatter pooled4 caseload
scatter nopool4 caseload

graph dot pooled4 nopool4 [w = caseload]if tid < 21, over(tid)
