clear all
set more off
set linesize 80

use mlm_cs_data1
mixed distress motivate || tid: , nolog
estimates store randint

*statsby, by(tid): regress distress motivate

statsby intercept = _b[_cons] slope = _b[motivate] ///
		int_se = _se[_cons] slope_se = _se[motivate] ///
		df = e(df_r), by(tid): regress distress motivate

summarize slope

generate ll_b = slope - (slope_se*(-1*invt(df, .025)))
generate ul_b = slope + (slope_se*(-1*invt(df, .025)))
egen therrank = rank(slope)

twoway scatter slope therrank || ///
	rcap ul_b ll_b therrank, ///
	ytitle("Motivate-distress slope") xtitle("Therapist rank") ///
	legend(off) ///
	scheme(lean2)
	

corr intercept slope

twoway scatter slope intercept || ///
	   lfit slope intercept, legend(off) ///
		ytitle("Therapist-specific slope") ///
		xtitle("Therapist-specific intercept") ylabel(-2(1)2) xlabel(-2(1)2) ///
		scheme(lean2)




use mlm_cs_data1, clear
mixed distress motivate || tid: motivate, cov(un) nolog
estimates store randslope

lrtest randint randslope

mixed, stddev

estat icc

predict u1 u0, reffects
generate est_inter = _b[_cons] + u0
generate est_slope = _b[motivate] + u1

twoway histogram distress, color(gs10%30) || ///
	  histogram est_inter, color(gs5%30) ///
	  legend(label(1 "Distress") label(2 "Intercept")) scheme(lean2)
  

twoway histogram distress, color(gs10%30) || ///
	  histogram est_slope, color(gs5%30) ///
	  legend(label(1 "Distress") label(2 "Slope")) scheme(lean2)



predict ex_distress, fitted
sort tid motivate
twoway scatter distress motivate, msymbol(circle_hollow) mcolor(gs10%50) || ///
	   line ex_distress motivate, lpattern(solid) connect(ascending) ///
	   ytitle("Distress") xtitle("Motivate") ///
	   legend(off) scheme(lean2)


